@@ -2,8 +2,10 @@
 from __future__ import unicode_literals, division, absolute_import
 import os
 import logging
-from flexget.plugin import register_plugin
+
+from flexget import plugin
 from flexget.entry import Entry
+from flexget.event import event
 
 log = logging.getLogger('listdir')
 
@@ -49,4 +51,6 @@ class Listdir(object):
         return entries
 
 
-register_plugin(Listdir, 'listdir', api_ver=2)
+@event('plugin.register')
+def register_plugin():
+    plugin.register(Listdir, 'listdir', api_ver=2)
